#!/bin/bash
# +--------------------------------------------------------------------+
# EFA update fix script 3.0.0.4
# Version 20140426
# +--------------------------------------------------------------------+
# Copyright (C) 2012~2014  http://www.efa-project.org
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
# +--------------------------------------------------------------------+

#----------------------------------------------------------------#
# Variables
#----------------------------------------------------------------#
logdir="/var/log/EFA"
gitdlurl="https://raw.github.com/E-F-A/v3"
mirror="http://dl.efa-project.org"
mirrorpath="update"
yumexclude="kernel* mysql* postfix* mailscanner* clamav*"
ADMINEMAIL="`cat /etc/EFA-Config | grep ADMINEMAIL | sed 's/.*://'`"
MAILFROM="$ADMINEMAIL"
MAILTO="$ADMINEMAIL"
MAILSUBJECT="EFA Update Complete For: `hostname`"
SENDMAIL="/usr/lib/sendmail"
TMPMAIL="/tmp/tempmail"
#----------------------------------------------------------------#

#----------------------------------------------------------------#
# get-update path
#----------------------------------------------------------------#
function get_update_path() {
  get_cversion
  if [[ $CVERSION == "EFA-3.0.0.4" ]]
   then
    update-3.0.0.3
    update-3.0.0.4
  fi  
}
#----------------------------------------------------------------#

#----------------------------------------------------------------#
# Update to EFA-3.0.0.4 fixes
#----------------------------------------------------------------#
function update-3.0.0.4() {

  echo "Staring update to E.F.A. 3.0.0.4 fixes"
  VERSION="3.0.0.4"
   
  #Issue #18 Email signature sanitation
  rm -f /usr/lib/MailScanner/MailScanner/CustomFunctions/CustomAction.pm
  /usr/bin/wget -O /usr/lib/MailScanner/MailScanner/CustomFunctions/CustomAction.pm $gitdlurl/$VERSION/build/EFA/CustomAction.pm --no-check-certificate
  EFASQLPWD=`grep EFASQLPWD /etc/EFA-Config | sed 's/^.*://'`
  sed -i "/^  my(\$db_pass) =/ c\  my(\$db_pass) = '$EFASQLPWD';" /usr/lib/MailScanner/MailScanner/CustomFunctions/CustomAction.pm
  /etc/init.d/MailScanner restart
    
  #Issue #65 Fix EFA-SA-Update file location
  rm -f /etc/cron.daily/EFA-SA-Update
  rm -f /usr/local/sbin/EFA-SA-Update
  /usr/bin/wget -O /usr/local/sbin/EFA-SA-Update $gitdlurl/$VERSION/build/EFA/EFA-SA-Update --no-check-certificate
  chmod 755 /usr/local/sbin/EFA-SA-Update
 
  echo "Update to 3.0.0.4 fixes complete." 
  echo ""
  echo "Please visit http://www.efa-project.org for more information."

  echo "From: $MAILFROM" > $TMPMAIL
  echo "To: $MAILTO" >> $TMPMAIL
  echo "Reply-To: $MAILFROM" >> $TMPMAIL
  echo "Subject: $MAILSUBJECT" >> $TMPMAIL
  echo "" >> $TMPMAIL
  echo "Update to 3.0.0.4 fixes complete." >> $TMPMAIL
  echo "" >> $TMPMAIL
  echo "Please visit http://www.efa-project.org for more information." >> $TMPMAIL
  cat $TMPMAIL | $SENDMAIL -t
  rm $TMPMAIL
}

#----------------------------------------------------------------#

#----------------------------------------------------------------#
# Update to EFA-3.0.0.3 fixes
#----------------------------------------------------------------#
function update-3.0.0.3() {

  echo "Staring update to E.F.A. 3.0.0.3 fixes"
  VERSION="3.0.0.3"

  # grab latest version of EFA-Configure
  rm -f /usr/local/sbin/EFA-Configure
  /usr/bin/wget -O /usr/local/sbin/EFA-Configure $gitdlurl/$VERSION/build/EFA/EFA-Configure --no-check-certificate
  chmod 700 /usr/local/sbin/EFA-Configure

  # Issue #16 System/db/settings backup
  mkdir -p /var/EFA/backup
  /usr/bin/wget -O /usr/local/sbin/EFA-Backup $gitdlurl/$VERSION/build/EFA/EFA-Backup --no-check-certificate
  chmod 700 /usr/local/sbin/EFA-Backup
  /usr/bin/wget -O /etc/cron.daily/EFA-Backup-cron $gitdlurl/$VERSION/build/EFA/EFA-Backup-cron --no-check-certificate
  chmod 700 /etc/cron.daily/EFA-Backup-cron

  # Issue #60 kam.cf.backup parsed by spamassassin
  mkdir -p /var/EFA/backup/KAM
  rm -f /etc/cron.daily/EFA-SA-Update
  /usr/bin/wget -O /etc/cron.daily/EFA-SA-Update $gitdlurl/$VERSION/build/EFA/EFA-SA-Update --no-check-certificate
  chmod 755 /etc/cron.daily/EFA-SA-Update

  # Issue #17 Trusted Network Rules
  touch /etc/sysconfig/EFA_trusted_networks
  yum -y install perl-Net-Netmask
  /usr/bin/wget -O /var/www/html/denylearned.html $gitdlurl/$VERSION/build/EFA/denylearned.html --no-check-certificate
  rm -f /var/www/cgi-bin/learn-msg.cgi
  /usr/bin/wget -O /var/www/cgi-bin/learn-msg.cgi $gitdlurl/$VERSION/build/EFA/learn-msg.cgi --no-check-certificate
  chmod 755 /var/www/cgi-bin/learn-msg.cgi
  EFASQLPWD=`grep EFASQLPWD /etc/EFA-Config | sed 's/^.*://'`
  sed -i "/^\$db_pass =/ c\$db_pass = \"$EFASQLPWD\";" /var/www/cgi-bin/learn-msg.cgi 
  
 # Notify admin of update completion and notes

  echo ""
  echo "Update to 3.0.0.3 fixes complete. "
  echo ""
  echo "Please visit http://www.efa-project.org for more information." 

  echo "From: $MAILFROM" > $TMPMAIL
  echo "To: $MAILTO" >> $TMPMAIL
  echo "Reply-To: $MAILFROM" >> $TMPMAIL
  echo "Subject: $MAILSUBJECT" >> $TMPMAIL
  echo "" >> $TMPMAIL
  echo "Update to 3.0.0.3 fixes complete." >> $TMPMAIL
  echo "" >> $TMPMAIL
  echo "Please visit http://www.efa-project.org for more information." >> $TMPMAIL
  cat $TMPMAIL | $SENDMAIL -t
  rm $TMPMAIL

}
#----------------------------------------------------------------#

#----------------------------------------------------------------#
# Function get current version number
#----------------------------------------------------------------#
function get_cversion() {
  if [ -f /etc/EFA-Version ]
    then
      CVERSION="`head -1 /etc/EFA-Version`" 
    else
      echo "ERROR: No valid version file found on this system." 
      echo "ERROR: exiting now"
      exit 0
  fi
  
  # Check if we run an beta version
  if [[ $CVERSION =~ ^EFA\-[0-9]{1}\.[0-9]{1}\.[0-9]{1}\.[0-9]{1}-beta$ ]]
    then
      echo "ERROR: You seem to be running an beta version, no upgrade possible."
      echo "ERROR: please look at http://www.efa-project.org for more information."
      echo "ERROR: exiting now"
      exit 0
  fi
  
  # Check if CVERSION is an valid Version file
  if ! [[ $CVERSION =~ ^EFA\-[0-9]{1}\.[0-9]{1}\.[0-9]{1}\.[0-9]{1}$ ]]
    then
      echo "ERROR: The version file on your system does not seem to be valid."
      echo "ERROR: exiting now"
      exit 0
  fi
}
#----------------------------------------------------------------#

#----------------------------------------------------------------#
# Check if we are root
#----------------------------------------------------------------#
function user_check() {
  if [ `whoami` == root ]
    then
      echo "[EFA] Good you are root"
  else
    echo "[EFA] Please become root to run this update"
    exit 0
  fi
}
#----------------------------------------------------------------#

#----------------------------------------------------------------#
# Where to start
#----------------------------------------------------------------#
user_check
get_update_path
